use strict;

use Test::More tests => 4;
use Test::Files;
use File::Spec;

my $skip_all = 0;

BEGIN {
    eval { require Gantry; };
    $skip_all = ( $@ ) ? 1 : 0;

    SKIP: {
        skip "tentmaker requires Gantry", 4 if $skip_all;
    }
    exit 0 if $skip_all;
}

use File::Spec;

use Bigtop::TentMaker qw/ -Engine=CGI -TemplateEngine=TT /;

my $tent_maker;
my @maker_deparse;
my $ajax_dir = File::Spec->catdir( qw( t tentmaker ajax_03 ) );
my $expected_file;
my $ajax;

#--------------------------------------------------------------------
# Sanity Check (repeated test from 02....t)
#--------------------------------------------------------------------

Bigtop::TentMaker->take_performance_hit();

my @correct_input = split /\n/, <<'EO_sample_input';
config {
    engine CGI;
    template_engine TT;
    Init Std {  }
    SQL SQLite {  }
    SQL Postgres {  }
    SQL MySQL {  }
    CGI Gantry { gen_root 1; with_server 1; flex_db 1; }
    Control Gantry { dbix 1; }
    Model GantryDBIxClass {  }
    SiteLook GantryDefault {  }
}
app Sample {
    config {
        dbconn `dbi:SQLite:dbname=app.db` => no_accessor;
        template_wrapper `genwrapper.tt` => no_accessor;
    }
}
EO_sample_input

$tent_maker = Bigtop::TentMaker->new();
$tent_maker->uri( '/' );
$tent_maker->root( 'tenttemplates' );

@maker_deparse = split /\n/, $tent_maker->deparsed();

is_deeply( \@maker_deparse, \@correct_input, 'simple sample deparse' );

#--------------------------------------------------------------------
# Add config statement to existing config block
#--------------------------------------------------------------------

$tent_maker->template_disable( 0 );

$ajax = $tent_maker->do_update_app_conf_statement(
            'new_conf_st',
            'new_value',
            'true'
) . "\n";

$expected_file = File::Spec->catfile( $ajax_dir, 'aconfst' );

file_ok( $expected_file, $ajax, 'add conf statement (aconfst)' );

#--------------------------------------------------------------------
# Add config statement when config block exists, but is empty
#--------------------------------------------------------------------

my $empty_config = File::Spec->catfile( 't', 'tentmaker', 'sample' );

Bigtop::TentMaker->take_performance_hit( $empty_config );

$tent_maker->template_disable( 0 );

$ajax = $tent_maker->do_update_app_conf_statement( 'new_conf_st', 'value' )
      . "\n";

$expected_file = File::Spec->catfile( $ajax_dir, 'aconfstempty' );

file_ok( $expected_file, $ajax, 'first conf statement (aconfstempty)' );

#--------------------------------------------------------------------
# Change statement value
#--------------------------------------------------------------------

$tent_maker->template_disable( 0 );

$ajax = $tent_maker->do_update_app_conf_statement(
            'new_conf_st',
            'other_value'
) . "\n";

$expected_file = File::Spec->catfile( $ajax_dir, 'cconfstempty' );

file_ok( $expected_file, $ajax, 'change first conf statement (cconfstempty)' );

